const Mesa = require('vendor/Mesa.js');
const ShopifyGraphql = require('vendor/ShopifyGraphql.js');
const Shopify= require('vendor/Shopify.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {
  script = (payload, context) => {
    let vars = context.steps;
    
    let query = `
      query discountsByEndsAt($query:String!) {
        codeDiscountNodes(first:10,query:$query) {
          nodes {
            id      
            codeDiscount {
              ... on DiscountCodeBasic {
                title
                summary
                customerSelection {
                  ... on DiscountCustomers {
                    customers {
                      id
                      email
                    }
                  }
                } 
                endsAt
                codes(first:1) {
                  edges {
                    node {
                      code
                    }
                  }
                }
              }
            }
          }
        }
      }
    `;

    let today = new Date();

    let fromDate = new Date();
    fromDate.setDate(today.getDate() + 7);
    let fromDateString = fromDate.toISOString().split('T')[0];

    let toDate = new Date();
    toDate.setDate(today.getDate() + 8);
    let toDateString = toDate.toISOString().split('T')[0];

    const r = ShopifyGraphql.send(query, {
      "query": `ends_at:>${fromDateString} AND ends_at:<${toDateString}`,
    }, {}, 'admin/api/2023-10/graphql.json');

    Mesa.output.next({"discounts": r.data.codeDiscountNodes.nodes});
  }
}
